#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_FRAC_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_FRAC_HPP_INCLUDED

#include <nt2/ieee/include/functions/scalar/frac.hpp>

#endif
